<div align='center'>

# Anipics

![PyPI - Downloads](https://img.shields.io/pypi/dm/anipics)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/anipics)
![PyPI - Format](https://img.shields.io/pypi/format/anipics)

![GitHub License](https://img.shields.io/github/license/D4n13l3k00/anipics)
![GitHub Release](https://img.shields.io/github/v/release/D4n13l3k00/anipics)

## 🖼 Simple module to get anime pictures

</div>

### 📥 Installation

```shell
# pip
$ pip install anipics

# poetry
$ poetry add anipics
```

### 🔑 Usage

You can see an example of use [here](/examples)

### Available services

- AnimePicsX
- NekosLife
- WaifuPics

### 📝 License

This project is under [AGPL-3.0 license](/LICENSE)
